import{O as r}from"./workspaceStore.d9227179.js";import{d as l,X as i,o as u,Y as c,b as a,w as d,u as o,aG as n,dd as f,dc as _}from"./index.82b3148c.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7adbd4dd-a98f-422f-8037-5822e55ce67a",e._sentryDebugIdIdentifier="sentry-dbid-7adbd4dd-a98f-422f-8037-5822e55ce67a")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:d(()=>[n("You're authenticated")]),_:1}),a(o(_),null,{default:d(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.ccd7fe3d.js.map
