import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.5a1b2abb.js";import{L as c}from"./tasksController.de8badda.js";import{d as f,e as u,o as _,c as m,w as a,b as s,u as o,dd as y,aG as i,bT as b,dh as k,a0 as w}from"./index.82b3148c.js";import{C as T}from"./ContentLayout.5eb06f3f.js";import{a as g}from"./ant-design.9b251c5e.js";import"./metadata.79e5a077.js";import"./PhRobot.vue.6eecdc74.js";import"./PhWebhooksLogo.vue.359fbd65.js";import"./string.ab0c206a.js";import"./dayjs.ad9fc9d3.js";import"./index.39ceca4f.js";import"./gateway.8733a5f3.js";import"./popupNotifcation.e1bf1f8c.js";import"./linters.38c38cf1.js";import"./asyncComputed.b31540a4.js";import"./scripts.10d6bd7a.js";import"./record.cb9a902e.js";import"./polling.e4e328fc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0dbd1519-b832-45e7-80be-399cf540e81e",e._sentryDebugIdIdentifier="sentry-dbid-0dbd1519-b832-45e7-80be-399cf540e81e")}catch{}})();const x=f({__name:"Tasks",setup(e){const t=new c,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(d,n)=>(_(),m(T,null,{default:a(()=>[s(o(k),{justify:"space-between",align:"center"},{default:a(()=>[s(o(y),null,{default:a(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:a(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.d8857947.js.map
