import{d as c,f as g,o as r,c as d,w as o,b as l,u as n,dh as i,$ as p,S as u,en as y,eo as b,bT as f,aW as m,ed as _}from"./index.82b3148c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8ad06a4a-d614-4a76-a674-969886ea500a",t._sentryDebugIdIdentifier="sentry-dbid-8ad06a4a-d614-4a76-a674-969886ea500a")}catch{}})();const h=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=g(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(a,k)=>s.value?(r(),d(n(m),{key:0,title:s.value},{default:o(()=>[l(n(f),y(b(a.$props)),{default:o(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[a.loading?u("",!0):p(a.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(r(),d(n(f),y(_({key:1},a.$props)),{default:o(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[a.loading?u("",!0):p(a.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{h as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.36fca7f4.js.map
