import{C as n,A as t}from"./CollapsePanel.fa92e55e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e0ed4a90-b609-4f5c-9970-58f582c8ac44",e._sentryDebugIdIdentifier="sentry-dbid-e0ed4a90-b609-4f5c-9970-58f582c8ac44")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.8fbc4239.js.map
