import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.a20fd51d.js";import{B as y}from"./BaseLayout.16b4e4b3.js";import{d as l,E as m,L as b,a0 as u,a_ as v,a$ as g,o as _,Y as h,a as s,Z as n,ec as w,eF as S,X as L,c as k,w as a,b as i,u as $}from"./index.82b3148c.js";import{u as x}from"./editor.5a271fd3.js";import{b as B}from"./index.9c784d83.js";import"./Logo.0be2686c.js";import"./workspaceStore.d9227179.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";import"./linters.38c38cf1.js";import"./asyncComputed.b31540a4.js";import"./index.cb0bcf94.js";import"./Avatar.c076649d.js";import"./index.867114ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2417b552-932c-4b76-b36c-446084dc98c2",e._sentryDebugIdIdentifier="sentry-dbid-2417b552-932c-4b76-b36c-446084dc98c2")}catch{}})();const I=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const P={class:"v-spinner"};function D(e,o,r,c,d,p){return v((_(),h("div",P,[s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u(I,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),r=S(),c=x();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){r.push({name:"error"});return}await c.createLogin(t).then(d),r.push({name:"workspace"})}),(t,C)=>(_(),k(y,null,{navbar:a(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:a(()=>[i(f)]),_:1})]),content:a(()=>[s("div",j,[i(R)])]),_:1}))}});const J=u(z,[["__scopeId","data-v-944edebb"]]);export{J as default};
//# sourceMappingURL=ProjectLogin.2007ab13.js.map
