import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.81120817.js";import{d as f,eF as m,ec as b,o as g,Y as y,b as w,u as a,a0 as k}from"./index.82b3148c.js";import{u as h}from"./workspaceStore.d9227179.js";import"./Logo.0be2686c.js";import"./string.ab0c206a.js";import"./OTPInput.0d867b22.js";import"./index.4f532519.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="04c295c6-b14d-47d4-b3ed-3df42455fcd9",e._sentryDebugIdIdentifier="sentry-dbid-04c295c6-b14d-47d4-b3ed-3df42455fcd9")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var c,d,u,p,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=a(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=a(r).state.workspace)==null?void 0:u.brandName,locale:(i=(p=a(r).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.5f084a2b.js.map
