import{U as a,dA as c,dB as i}from"./index.82b3148c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="eed22bd5-d210-44f3-b3cf-384984ee3dd1",e._sentryDebugIdIdentifier="sentry-dbid-eed22bd5-d210-44f3-b3cf-384984ee3dd1")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:o}=c(i),u=a(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{u as D,r as M,d as Q,o as R,t as W};
//# sourceMappingURL=dayjs.ad9fc9d3.js.map
