import{d as n,o as s,Y as a,a as d,$ as r,ei as l,a0 as _}from"./index.82b3148c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f498fa19-bdd9-44e0-a317-71f6855052cb",e._sentryDebugIdIdentifier="sentry-dbid-f498fa19-bdd9-44e0-a317-71f6855052cb")}catch{}})();const f={class:"content-layout"},c=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),a("div",f,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(c,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.5eb06f3f.js.map
