import{b as r,u as n}from"./workspaceStore.d9227179.js";import{W as c}from"./PlayerConfigProvider.e3cb5ce0.js";import{d,g as i,r as f,u as o,o as p,c as u,w as l,S as _,b as m}from"./index.82b3148c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="aa1966a5-af3b-4de0-95c1-93ed78f985c3",t._sentryDebugIdIdentifier="sentry-dbid-aa1966a5-af3b-4de0-95c1-93ed78f985c3")}catch{}})();const h=d({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=f("RouterView");return o(e).state.workspace?(p(),u(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.b71239c8.js.map
