import{C as a}from"./gateway.8733a5f3.js";import"./index.82b3148c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4c13d01f-16c0-4ea3-8b43-54c78a8b0acb",t._sentryDebugIdIdentifier="sentry-dbid-4c13d01f-16c0-4ea3-8b43-54c78a8b0acb")}catch{}})();class i{async create(e){return a.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return a.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return a.get(`organizations/${e}/members`)}async get(e,n){return a.get(`organizations/${e}/members/${n}`)}async update(e,n,r){return a.patch(`organizations/${e}/members/${n}`,r)}}export{i as M};
//# sourceMappingURL=member.0ec96179.js.map
