import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.82b3148c.js";import"./linters.38c38cf1.js";import{W as s}from"./workspaces.114e35d6.js";import{C as d}from"./ContentLayout.5eb06f3f.js";import{a as f}from"./controller.68d805d6.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.c25c1f5f.js";import"./asyncComputed.b31540a4.js";import"./workspaceStore.d9227179.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";import"./record.cb9a902e.js";import"./gateway.8733a5f3.js";import"./popupNotifcation.e1bf1f8c.js";import"./fetch.4e9ad82b.js";import"./PhPencil.vue.fb0b2f4b.js";import"./SaveButton.d3935f5f.js";import"./UnsavedChangesHandler.d162f298.js";import"./ExclamationCircleOutlined.280af49b.js";import"./CrudView.8dac6e2f.js";import"./router.aacfb520.js";import"./Badge.8b0acfd8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b4d03e94.js";import"./BookOutlined.e58a4796.js";import"./PhDotsThreeVertical.vue.c0360e2e.js";import"./index.39ceca4f.js";import"./index.867114ba.js";import"./polling.e4e328fc.js";import"./index.4f532519.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d2094698-a1d5-4835-9973-e5ac0539b395",o._sentryDebugIdIdentifier="sentry-dbid-d2094698-a1d5-4835-9973-e5ac0539b395")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(p(),n(d,null,{default:m(()=>[a(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.f70c5604.js.map
