import{_ as y}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.a20fd51d.js";import{C as b}from"./ContentLayout.5eb06f3f.js";import{l as h}from"./fetch.4e9ad82b.js";import{d as w,eF as g,ec as k,e as v,o as r,c,w as n,b as u,a as C,u as d,d9 as p,aG as _,a0 as x}from"./index.82b3148c.js";import{u as I,E as T}from"./editor.5a271fd3.js";import{C as D}from"./Card.cef79d50.js";import"./Logo.0be2686c.js";import"./workspaceStore.d9227179.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";import"./linters.38c38cf1.js";import"./asyncComputed.b31540a4.js";import"./TabPane.3a7649ae.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6c1f4a7f-9974-4f08-b2d9-d89f837fdfe8",e._sentryDebugIdIdentifier="sentry-dbid-6c1f4a7f-9974-4f08-b2d9-d89f837fdfe8")}catch{}})();const L={class:"card-content"},N=w({__name:"Welcome",setup(e){const o=g(),{query:i}=k(),a=I();a.loadLogin();const f=v(!0),l=async()=>{f.value=!1,setInterval(()=>{var t;return window.location.replace(((t=a==null?void 0:a.links)==null?void 0:t.project)||T.consoleUrl)},5e3)};return(async()=>{const t=i.token,s=await h("/_editor/web-editor/welcome",{method:"POST",body:JSON.stringify({token:t}),headers:{"Content-Type":"application/json"}});if(!s.ok)return l();const{ok:m}=await s.json();if(!m)return l();await o.push({name:"workspace"})})(),(t,s)=>(r(),c(b,null,{default:n(()=>[u(d(D),{bordered:!1,class:"card"},{default:n(()=>[C("div",L,[u(y,{style:{"margin-bottom":"10px"}}),f.value?(r(),c(d(p),{key:0},{default:n(()=>[_("Loading...")]),_:1})):(r(),c(d(p),{key:1},{default:n(()=>[_("Authentication failed. You are been redirected...")]),_:1}))])]),_:1})]),_:1}))}});const J=x(N,[["__scopeId","data-v-a984ec04"]]);export{J as default};
//# sourceMappingURL=Welcome.493f4c6e.js.map
