import{d as h,eF as A,r as B,u as e,o as s,c as i,by as C,Y as m,b as a,w as t,aG as r,bT as d,a as f,dc as w,ea as _,cO as N,ep as I,e9 as L,eg as S,aS as g,S as D,$ as z,a0 as R}from"./index.82b3148c.js";import{a as $}from"./asyncComputed.b31540a4.js";import{G as T}from"./PhChats.vue.ed7527c2.js";import{F as V}from"./PhSignOut.vue.9498f732.js";import{C as F}from"./router.aacfb520.js";import{a as k}from"./gateway.8733a5f3.js";import{A as E}from"./index.867114ba.js";import{A as G}from"./Avatar.c076649d.js";import{B as O,A as P,b as j}from"./index.9c784d83.js";import{B as q}from"./BookOutlined.e58a4796.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="10bd50cc-2873-4160-a4a4-01b13360bb6b",n._sentryDebugIdIdentifier="sentry-dbid-10bd50cc-2873-4160-a4a4-01b13360bb6b")}catch{}})();const H={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},M={style:{display:"flex","flex-direction":"column",gap:"10px"}},U={style:{display:"flex",gap:"5px"}},Y=h({__name:"LoginBlock",setup(n){function o(b){const y=b.split("@")[0];return I.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const c=A(),{result:l,loading:p,refetch:x}=$(async()=>k.getAuthor());function v(){k.removeAuthor(),F.shutdown(),x(),c.push({name:"login"})}return(b,y)=>{const u=B("RouterLink");return e(p)?(s(),i(e(C),{key:0})):e(l)?(s(),m("div",H,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(T),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(N),{placement:"bottomRight"},{content:t(()=>[f("div",M,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[f("div",U,[a(e(V),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(E),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(G),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(u,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),J={class:"extra"},K=h({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(j),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(O),{key:0},{default:t(()=>[(s(!0),m(g,null,L(o.breadcrumb,(l,p)=>(s(),i(e(P),{key:p},{default:t(()=>[a(e(S),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),extra:t(()=>[f("div",J,[a(e(d),{class:"docs-button",href:"https://abstra.io/docs/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(q))]),default:t(()=>[o.$slots.default?z(o.$slots,"default",{key:0},void 0,!0):(s(),m(g,{key:1},[r("Docs")],64))]),_:3}),a(Y)])]),_:3}))}});const ne=R(K,[["__scopeId","data-v-89ff1b2a"]]);export{ne as N};
//# sourceMappingURL=Navbar.57310a5c.js.map
