import{B as r}from"./BookOutlined.e58a4796.js";import{d as c,o as a,c as f,w as o,b,u as n,$ as l,Y as u,aG as i,aS as p,bT as y}from"./index.82b3148c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="db8c359b-ebdd-4834-b89a-b20263f0f4dc",t._sentryDebugIdIdentifier="sentry-dbid-db8c359b-ebdd-4834-b89a-b20263f0f4dc")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,d)=>{var s;return a(),f(n(y),{class:"docs-button",href:`https://abstra.io/docs/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[b(n(r))]),default:o(()=>[e.$slots.default?l(e.$slots,"default",{key:0}):(a(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.b4d03e94.js.map
