import{O as r}from"./workspaceStore.d9227179.js";import{d as i,X as l,o as u,Y as c,b as a,w as n,u as o,aG as d,dd as f,dc as b}from"./index.82b3148c.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="07126e71-5741-4dfe-ba37-c04d18f1b50a",e._sentryDebugIdIdentifier="sentry-dbid-07126e71-5741-4dfe-ba37-c04d18f1b50a")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.2086a099.js.map
