import{P as m}from"./PlayerNavbar.fa8c3606.js";import{d as g,eF as h,ec as c,e as y,f as b,r as k,o as i,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.82b3148c.js";import{u as V}from"./workspaceStore.d9227179.js";import"./metadata.79e5a077.js";import"./PhRobot.vue.6eecdc74.js";import"./PhWebhooksLogo.vue.359fbd65.js";import"./LoadingOutlined.5a8eb0fc.js";import"./PhSignOut.vue.9498f732.js";import"./index.cb0bcf94.js";import"./Avatar.c076649d.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="79387bff-dba2-4a1e-94d0-56312f115c92",o._sentryDebugIdIdentifier="sentry-dbid-79387bff-dba2-4a1e-94d0-56312f115c92")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=y(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const f=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(m,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.d25293f6.js.map
