import{C as a}from"./gateway.8733a5f3.js";import"./index.82b3148c.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="2120142a-f0f1-40de-9b57-f7c0907da4ea",r._sentryDebugIdIdentifier="sentry-dbid-2120142a-f0f1-40de-9b57-f7c0907da4ea")}catch{}})();class s{async list(e){return a.get(`organizations/${e}/folders`)}async create(e){return a.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return a.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return a.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.39a8b662.js.map
