import{k as i,T as n,m as r,P as o,C as c,M as d,s as p,n as s,p as m,q as u,t as f,v as g}from"./index.82b3148c.js";import{s as y,c as l,a}from"./workspaceStore.d9227179.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.b71239c8.js";import"./url.3209a6f7.js";import"./colorHelpers.d4cbfb24.js";import"./PlayerConfigProvider.e3cb5ce0.js";import"./index.d5ff2b7b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="c3da1ac4-5022-4943-a6c3-2ae704c4a9cb",t._sentryDebugIdIdentifier="sentry-dbid-c3da1ac4-5022-4943-a6c3-2ae704c4a9cb")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=i({render:()=>m(b)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",d),e.component("Message",p),s(e,u),s(e,f),s(e,g)})();
//# sourceMappingURL=player.c875a7a4.js.map
