import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.5a1b2abb.js";import{R as f}from"./tasksController.de8badda.js";import{d as b,ec as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.82b3148c.js";import"./gateway.8733a5f3.js";import{a as j,B as x}from"./build.266f1e37.js";import{a as C}from"./project.24dc9c6f.js";import"./tables.b60a390b.js";import{a as D}from"./asyncComputed.b31540a4.js";import"./metadata.79e5a077.js";import"./PhRobot.vue.6eecdc74.js";import"./PhWebhooksLogo.vue.359fbd65.js";import"./ant-design.9b251c5e.js";import"./string.ab0c206a.js";import"./dayjs.ad9fc9d3.js";import"./index.39ceca4f.js";import"./linters.38c38cf1.js";import"./scripts.10d6bd7a.js";import"./record.cb9a902e.js";import"./polling.e4e328fc.js";import"./popupNotifcation.e1bf1f8c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="49892a0b-4e82-43fb-bf27-3f9b2aff1b41",e._sentryDebugIdIdentifier="sentry-dbid-49892a0b-4e82-43fb-bf27-3f9b2aff1b41")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:c}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.0de76e51.js.map
