import{C as p}from"./controller.68d805d6.js";import{d as i,ec as n,o as s,c as a,u as m}from"./index.82b3148c.js";import{_ as f}from"./View.vue_vue_type_script_setup_true_lang.c25c1f5f.js";import"./gateway.8733a5f3.js";import"./popupNotifcation.e1bf1f8c.js";import"./fetch.4e9ad82b.js";import"./record.cb9a902e.js";import"./PhPencil.vue.fb0b2f4b.js";import"./SaveButton.d3935f5f.js";import"./UnsavedChangesHandler.d162f298.js";import"./ExclamationCircleOutlined.280af49b.js";import"./CrudView.8dac6e2f.js";import"./router.aacfb520.js";import"./Badge.8b0acfd8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b4d03e94.js";import"./BookOutlined.e58a4796.js";import"./url.3209a6f7.js";import"./PhDotsThreeVertical.vue.c0360e2e.js";import"./index.39ceca4f.js";import"./index.867114ba.js";import"./asyncComputed.b31540a4.js";import"./polling.e4e328fc.js";import"./index.4f532519.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="612ff7f2-441c-4e6e-aeaf-4ad50fca85d2",o._sentryDebugIdIdentifier="sentry-dbid-612ff7f2-441c-4e6e-aeaf-4ad50fca85d2")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(c,d)=>(s(),a(f,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.815fa01e.js.map
