import{d as a,o,Y as s,b as d,u as c,by as r,a0 as _}from"./index.82b3148c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="af7f1b5e-415c-45f4-9032-c1b09148da8c",e._sentryDebugIdIdentifier="sentry-dbid-af7f1b5e-415c-45f4-9032-c1b09148da8c")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.aea352cd.js.map
