import{d as l,em as c,f as r,o,Y as t,S as d,ei as f,ea as p,a0 as u}from"./index.82b3148c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="42747802-e7cb-42f0-8574-0a52479df44b",e._sentryDebugIdIdentifier="sentry-dbid-42747802-e7cb-42f0-8574-0a52479df44b")}catch{}})();const _={class:"logo"},g=["src","alt"],m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),i=r(()=>`${s.brandName} Logo`);return(a,y)=>(o(),t("div",_,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:i.value},null,8,g)):d("",!0),a.hideText?d("",!0):(o(),t("span",{key:1,class:f(a.size)},p(a.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.0be2686c.js.map
